@@ -276,17 +276,6 @@ class LogStash::Runner < Clamp::StrictCommand
     LogStash::PLUGIN_REGISTRY.hooks.register_emitter(self.class, @dispatcher)
 
     @settings.validate_all
-
-    if @settings.registered?("xpack.monitoring.enabled")
-      verify_deprecated_setting("xpack.monitoring.elasticsearch.url", "xpack.monitoring.elasticsearch.hosts")
-      verify_deprecated_setting("xpack.monitoring.elasticsearch.ssl.ca", "xpack.monitoring.elasticsearch.ssl.certificate_authority")
-    end
-
-    if @settings.registered?("xpack.management.enabled")
-      verify_deprecated_setting("xpack.management.elasticsearch.url", "xpack.management.elasticsearch.hosts")
-      verify_deprecated_setting("xpack.management.elasticsearch.ssl.ca", "xpack.management.elasticsearch.ssl.certificate_authority")
-    end
-
     @dispatcher.fire(:before_bootstrap_checks)
 
     return start_shell(setting("interactive"), binding) if setting("interactive")
@@ -380,6 +369,8 @@ class LogStash::Runner < Clamp::StrictCommand
 
     @agent.shutdown
 
+    logger.info("Logstash shut down.")
+
     # flush any outstanding log messages during shutdown
     org.apache.logging.log4j.LogManager.shutdown
 
@@ -512,15 +503,4 @@ class LogStash::Runner < Clamp::StrictCommand
     @settings.get_value(key)
   end
 
-  def verify_deprecated_setting(old_setting, new_setting)
-    if @settings.set?(old_setting)
-      logger.warn("Deprecated setting `#{old_setting}` please use `#{new_setting}`")
-      if @settings.set?(new_setting)
-        signal_usage_error("Both `#{new_setting}` and the deprecated `#{old_setting}` settings are set, please remove `#{old_setting}`")
-      else
-        @settings.set_value(new_setting, @settings.get_value(old_setting))
-      end
-    end
-  end
-
 end
